@@ -1,6 +1,6 @@
-"""Reference support for pydantic models"""
+"""Hyperlinks for pydantic models"""
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 from .href import Href, Referrable
 from .model import BaseReferrableModel
